# baserelease defines which build revision of this version we're building.
# The magical name baserelease is matched by the rpmdev-bumpspec tool, which
# you should use.
%global baserelease 1

# On a released (stable or beta) version set it to 1
%define is_release 1
# On a stable version set it to 1
%define is_stable 1

# On a pre-release packages set this to the selected name
%define prerelease_name beta-1

# On a snapshot packages set this to the selected date and commit.
%define prerelease_date 1380299441
%define prerelease_timestamp 20130930

# pkg_release is what we'll fill in for the rpm Release: field
%if %{is_release}
    %if %{is_stable}
        # stable release
        %define pkg_release %{baserelease}%{?dist}
%else
        # alpha or beta release
        %define escaped_prerelease_name %(echo %{prerelease_name} |tr -cd [:alnum:])
        %define pkg_release 0.%{baserelease}.%{escaped_prerelease_name}%{?dist}
    %endif
%else
    # nightly build
    %define pkg_release 0.%{baserelease}.%{prerelease_date}snap%{?dist}
%endif

Name:           scilab
Version:        5.5.0
Release:        %{pkg_release}
Summary:        Scientific software package for numerical computations

Group:          Applications/Engineering
License:        CeCILL
URL:            http://www.scilab.org/
%if %{is_release}
    %if %{is_stable}
        # stable release
Source0:        http://www.scilab.org/download/%{version}/scilab-%{version}-src.tar.gz
%else
        # alpha or beta release
Source0:        http://www.scilab.org/download/%{version}-%{prerelease_name}/scilab-%{version}-%{prerelease_name}-src.tar.gz
    %endif
%else
    # nightly build
Source0:        http://downloadarea.scilab.org/download/%(date -d%{prerelease_date} +%%Y-%%m-%%d)/scilab-master-%{prerelease_timestamp}-src.tar.gz
%endif

# Bug 767102 - help() should suggest scilab-doc
Patch1:         %{name}-0001-Use-pkcon-to-install-doc-package.patch
# Fix jdk6, jdk7 or jdk8
Patch2:         %{name}-0002-enable-jdk8.patch
# Fix some gcc-4.9 asan issues
Patch3:         %{name}-0003-fix-asan-issues.patch
# Fix make doc-ja_JP
Patch4:         %{name}-0004-fix-make-doc-ja_JP.patch
# Pass appdata-validate
Patch5:         %{name}-0005-fix-appdata.patch

# Dependencies are extracted from :
# "http://wiki.scilab.org/Dependencies of Scilab 5.X"

# Mandatory
BuildRequires:  gcc-gfortran

## for dynamic link features
Requires:       gcc
Requires:       gcc-c++
Requires:       gcc-gfortran

# Core
BuildRequires:  libxml2-devel
BuildRequires:  pcre-devel
BuildRequires:  ncurses-devel
BuildRequires:  libcurl-devel

# Numerical libraries
# see "http://wiki.scilab.org/Linalg performances"
# TBD Packaging guidelines https://fedorahosted.org/fpc/ticket/352
BuildRequires:  lapack-devel
BuildRequires:  arpack-devel

# GUI/Console
BuildRequires:  jpackage-utils
BuildRequires:  java-devel
BuildRequires:  ant

BuildRequires:  flexdock
BuildRequires:  scirenderer
BuildRequires:  jogl2
BuildRequires:  mesa-libGL-devel

Requires:       flexdock
Requires:       scirenderer
Requires:       jogl2

BuildRequires:  jrosetta
Requires:       jrosetta

BuildRequires:  apache-commons-logging
BuildRequires:  javahelp2
BuildRequires:  jlatexmath
BuildRequires:  jlatexmath-fop
BuildRequires:  jgraphx
BuildRequires:  fop
BuildRequires:  jeuclid
BuildRequires:  batik
BuildRequires:  xmlgraphics-commons

Requires:       apache-commons-logging
Requires:       javahelp2
Requires:       jlatexmath
Requires:       jlatexmath-fop
Requires:       jgraphx
Requires:       fop
Requires:       jeuclid
Requires:       batik
Requires:       xmlgraphics-commons

# TCL/TK features
BuildRequires:  tcl-devel
BuildRequires:  tk-devel

Requires:       tcl
Requires:       tk

# Modelica
BuildRequires:  ocaml

# Documentation
BuildRequires:  saxon
BuildRequires:  docbook-style-xsl
BuildRequires:  liberation-sans-fonts

# QA tests and validation
BuildRequires:  checkstyle
BuildRequires:  junit4
BuildRequires:  cobertura

# All optional dependencies are needed to provide a full-featured Scilab
BuildRequires:  gettext-devel
BuildRequires:  fftw-devel
BuildRequires:  matio-devel
BuildRequires:  suitesparse-devel
BuildRequires:  hdf5-devel

# hdf5 does not bump soname but check at runtime
Requires:       hdf5 = %{_hdf5_version}

# Specific dependencies for packaging purpose
BuildRequires:  desktop-file-utils
BuildRequires:  appdata-tools

%description
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

%package devel
Group:          Applications/Engineering
License:        CeCILL

Summary:        Scientific software package for numerical computations (include files)

Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide include files for Scilab.

%package doc
Group:          Documentation
License:        CeCILL

Summary:        Scientific software package (documentation files)

BuildArch:      noarch
# See https://bugzilla.redhat.com/show_bug.cgi?id=993239
ExcludeArch:    %{arm}
Requires:       %{name} = %{version}-%{release}

%description doc
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide documentation files for Scilab.

%package tests
Group:          Applications/Engineering
License:        CeCILL

Summary:        Provides test files for Scilab

BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       testng

%description tests
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide test files for Scilab.

%prep
%if %{is_release}
    %if %{is_stable}
%setup -q
%else
%setup -q -n %{name}-%{version}-%{prerelease_name}
    %endif
%else
%setup -q -n %{name}-master-%{prerelease_timestamp}
%endif

%patch1 -p1 -b .pkgcon
%patch2 -p1 -b .jdk8
%patch3 -p1 -b .asan
%patch4 -p1 -b .ja_JP-doc
%patch5 -p1 -b .validate

# Fix Class-Path in manifest
sed -i '/name="Class-Path"/d' build.incl.xml

# Fix file-not-utf8
iconv -f ISO_8859-1 -t UTF-8 COPYING >COPYING.utf8
mv COPYING.utf8 COPYING

# Cleanup the builder's home
rm -fr ~/.Scilab

%build
# disable-static-system-lib: do not static link with compiler libs
# without-emf: disabled because freehep-*.jar are not packaged in fedora and
#              it is a windows specific format
%configure --disable-static-system-lib --without-emf

make %{?_smp_mflags}
make %{?_smp_mflags} doc

%install
make %{?_smp_mflags} install DESTDIR=%{buildroot}
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
appdata-validate -relax %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%find_lang %{name}

# Remove more advanced repl, user should use CLI options instead
rm -fr %{buildroot}%{_datadir}/applications/%{name}-*.desktop
# Remove la files
rm -fr %{buildroot}%{_libdir}/%{name}/*.la

# Add localized help files to scilab-doc.lang
# adapted from find-lang.sh
# always provide the english help to handle missing localized help pages
find %{buildroot}%{_datadir}/%{name}/modules/helptools/jar -type f -o -type l|sed '
s:'"%{buildroot}"'::
s:\(.*/'"%{name}"'_\)\([^\._]\+\)\(.*\.jar$\):%lang(\2) \1\2\3:
s:^\([^%].*\)::
s:%lang(en) ::
s:%lang(C) ::
/^$/d' |tee %{name}-doc.lang

%check
make check-TESTS

%post
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_bindir}/*
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/mime/packages/%{name}.xml
# part of scilab-devel
%exclude %{_datadir}/%{name}/contrib
%exclude %{_datadir}/%{name}/tools
# part of scilab-doc
%exclude %{_datadir}/%{name}/modules/helptools/jar/%{name}_*.jar
%exclude %{_datadir}/%{name}/modules/*/examples
%exclude %{_datadir}/%{name}/modules/*/help
%exclude %{_datadir}/%{name}/modules/*/javadoc
# part of scilab-tests
%exclude %{_datadir}/%{name}/modules/*/tests

%files devel
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/contrib
%{_datadir}/%{name}/tools

%files doc -f %{name}-doc.lang
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_datadir}/doc/%{name}-*
%{_datadir}/%{name}/modules/*/examples
%{_datadir}/%{name}/modules/*/help
%{_datadir}/%{name}/modules/*/javadoc

%files tests
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_datadir}/%{name}/modules/*/tests

%changelog
* Fri Apr 11 2014 Clément David <c.david86@gmail.com> - 5.5.0-1
- Update to 5.5.0

* Fri Dec 27 2013 Orion Poplawski <orion@cora.nwra.com> - 5.5.0-0.3.beta1.1
- Rebuild for hdf5 1.8.12

* Fri Dec 06 2013 Nils Philippsen <nils@redhat.com> - 5.5.0-0.2.beta1.1
- rebuild (suitesparse)

* Wed Oct 02 2013 Clément David <c.david86@gmail.com> - 5.5.0-0.1.beta1
- Update to 5.5.0-beta-1

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.4.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon May 20 2013 Clément David <c.david86@gmail.com> - 5.4.1-4
- Enable matio 1.5
- Add some optional (QA) dependencies

* Fri May 17 2013 Orion Poplawski <orion@cora.nwra.com> - 5.4.1-3
- Add patch to fix i686 build by using dynamic stack

* Fri May 17 2013 Clément David <c.david86@gmail.com> - 5.4.1-3
- Fix the build, i686 built had failures on macro generation.

* Thu May 16 2013 Orion Poplawski <orion@cora.nwra.com> - 5.4.1-2
- Rebuild for hdf5 1.8.11

* Fri Mar 29 2013 Clément David <c.david86@gmail.com> - 5.4.1-1
- Update to 5.4.1
- disable matio 1.5

* Thu Feb 21 2013 Clément David <c.david86@gmail.com> - 5.4.0-4
- Remove the jdf5 dependency

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Dec 05 2012 Orion Poplawski <orion@cora.nwra.com> - 5.4.0-2
- Rebuild for hdf5 1.8.10

* Tue Oct 30 2012 Clément David <c.david86@gmail.com> - 5.4.0-1
- Update to 5.4.0

* Tue Jul 24 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.6.20120403snap
- Rebuilt for hdf5 1.8.9
- Backport matio 1.5.0 support
- Use pkcon to provide help package on demand

* Tue May 15 2012 Orion Poplawski <orion@cora.nwra.com> - 5.4.0-0.5.20120403snap
- Rebuild for hdf5 1.8.9
- Add patch to build against matio 1.5.0

* Fri Apr 27 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.4.20120403snap
- rebuilt

* Tue Apr 03 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.3.20120403snap
- Add the arpack dependency

* Tue Apr 03 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.2.20120403snap
- Fix build after merge

* Tue Apr 03 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.1.20120403snap
- Update to 5.4.0 nightly builds

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.3.3-10
- Rebuilt for c++ ABI breakage

* Fri Feb 10 2012 Clément David <c.david86@gmail.com> - 5.3.3-9
- Update classpath.xml due to the jhdf5 move.

* Fri Feb 10 2012 Petr Pisar <ppisar@redhat.com> - 5.3.3-8
- Rebuild against PCRE 8.30

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.3.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jan  2 2012 Clément David <c.david86@gmail.com> - 5.3.3-6
- Update classpath.xml due to the flexdock move.

* Tue Nov 22 2011 Clément David <c.david86@gmail.com> - 5.3.3-5
- use %{_hdf5_version} to avoid runtime crash

* Thu Nov 17 2011 Clément David <c.david86@gmail.com> - 5.3.3-4
- use %{hdf5ver} to avoid runtime crash

* Wed Nov  9 2011 <c.david86@gmail.com> 5.3.3-3
- Remove dependency on atlas (need only lapack ABI)
- Use noarch package on doc and tests
- Remove ldconfig on post/postun
- add a default font for doc generation
- scilab does not depends on scilab-doc anymore

* Sun Oct 30 2011 <c.david86@gmail.com> 5.3.3-2
- Use rpm auto dependency
- add minimal versions for flexdock and jrosetta

* Sun Oct 30 2011 <c.david86@gmail.com> 5.3.3-1
- First package

